@@ -105,14 +105,14 @@ static void
 halt(GtkWidget * widget, gpointer data)
 {
     GError **error = NULL;
-    g_spawn_command_line_async("/sbin/poweroff -p", error);
+    g_spawn_command_line_async("/sbin/poweroff -fp", error);
 }
 
 static void
 reboot(GtkWidget * widget, gpointer data)
 {
     GError **error = NULL;
-    g_spawn_command_line_async("/sbin/reboot -p", error);
+    g_spawn_command_line_async("/sbin/reboot -fp", error);
 }
 
 gboolean
