@@ -1,8 +1,31 @@
 /*
  * get_ipaddr()
- * (C) James A. McQuillan, 2000
- *
- * This software is licensed under the GNU GLPv2.
+ * Copyright James A. McQuillan, 2000
+
+ * Author: James A. McQuillan <jam@McQuil.com>
+
+ * 2007, Oliver Grawert <ogra@canonical.com>
+ * 2008, Ryan Niebur <RyanRyan52@gmail.com>
+ *       Scott Balneaves <sbalneav@ltsp.org>
+ *       Warren Togami <wtogami@redhat.com>
+ *       Toshio Kuratomi
+ * 2009, Ryan Niebur <RyanRyan52@gmail.com>
+
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2.
+
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, you can find it on the World Wide
+ * Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+
  */
 
 #include <sys/utsname.h>
@@ -10,6 +33,7 @@
 #include <sys/ioctl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <signal.h>
 #include <unistd.h>
 #include <net/if.h>
 #include <netinet/in.h>
@@ -23,7 +47,7 @@
 #include "ldm.h"
 
 void
-get_ipaddr()
+get_ipaddr(void)
 {
     int numreqs = 10;
     struct ifconf ifc;
@@ -50,7 +74,7 @@ get_ipaddr()
             die(_("Out of memory"));
 
 	    if (ioctl(skfd, SIOCGIFCONF, &ifc) < 0) {
-            fprintf(ldmlog, _("SIOCGIFCONF\n"));
+            logerr("SIOCGIFCONF");
 	        goto out;
 	    }
 
@@ -75,7 +99,7 @@ get_ipaddr()
 
 	    strcpy(info.ifr_name, ifr->ifr_name);
 	    if (ioctl(skfd, SIOCGIFFLAGS, &info) < 0) {
-            fprintf(ldmlog, _("SIOCGIFFLAGS\n"));
+            logerr("SIOCGIFFLAGS");
 	        goto out;
 	    }
 
